==> inflector-gadget-0.3.2.tar.bz2: inflector-gadget-0.3.2/README.md <==
inflector-gadget
================

Inflection mapping gadget for complex quadratic polynomials.

keyboard controls for navigation
--------------------------------

        ESC, Q  quit
        H       show this help
        HOME    reset view
        UP      zoom in (faster with SHIFT)
        DOWN    zoom out (faster with SHIFT)
        J       Julia mode
        M       Mandelbrot mode
        C       toggle centering mode
        D       use double precision (requires OpenGL 4)
        F       use single precision (default)
        0       reset inflections
        -       undo add inflection point
        =       redo add inflection point
        S       save screenshot (in PPM format)

keyboard controls for animation
-------------------------------

        SPACE   add keyframe
        DELETE  delete keyframe
        LEFT    activate previous keyframe
        RIGHT   activate next keyframe
        ENTER   play animation (press again to stop)
        [       play slower (more with SHIFT)
        ]       play faster (more with SHIFT)
        V       (with SHIFT) save image sequence (in PPM format)

mouse controls
--------------

        WHEEL   zoom about mouse cursor position
        LEFT    add inflection point at cursor position
        RIGHT   undo add inflection point
        MIDDLE  recenter window about mouse cursor position

legal
-----

inflector-gadget 0.3.2 (GPL) 2017-11-10 Claude Heiland-Allen

inflector-gadget is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

inflector-gadget is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with inflector-gadget.  If not, see <http://www.gnu.org/licenses/>.

==> inflector-gadget-0.4.tar.bz2: inflector-gadget-0.4/README.md <==
inflector-gadget
================

Inflection mapping gadget for complex quadratic polynomials.

keyboard controls for navigation
--------------------------------

        ESC, Q  quit
        H       show this help
        HOME    reset view
        UP      zoom in (faster with SHIFT)
        DOWN    zoom out (faster with SHIFT)
        J       Julia mode
        M       Mandelbrot mode
        C       toggle centering mode
        D       use double precision (requires OpenGL 4)
        F       use single precision (default)
        0       reset inflections
        -       undo add inflection disc
        =       redo add inflection disc
        S       save screenshot (in PPM format)

keyboard controls for animation
-------------------------------

        SPACE   add keyframe
        DELETE  delete keyframe
        LEFT    activate previous keyframe
        RIGHT   activate next keyframe
        ENTER   play animation (press again to stop)
        [       play slower (more with SHIFT)
        ]       play faster (more with SHIFT)
        V       (with SHIFT) save image sequence (in PPM format)

mouse controls
--------------

        WHEEL   zoom about mouse cursor position
        LEFT    drag and release to add inflection disc at cursor position
        RIGHT   undo add inflection point
        MIDDLE  recenter window about mouse cursor position

legal
-----

inflector-gadget 0.4 (GPL) 2017-12-14 Claude Heiland-Allen

inflector-gadget is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

inflector-gadget is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with inflector-gadget.  If not, see <http://www.gnu.org/licenses/>.
